==> ec2-2.10.83-sources.jar: software/amazon/awssdk/services/ec2/paginators/DescribePublicIpv4PoolsIterable.java <==
/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */

package software.amazon.awssdk.services.ec2.paginators;

import java.util.Collections;
import java.util.Iterator;
import java.util.function.Function;
import software.amazon.awssdk.annotations.Generated;
import software.amazon.awssdk.core.pagination.sync.PaginatedItemsIterable;
import software.amazon.awssdk.core.pagination.sync.PaginatedResponsesIterator;
import software.amazon.awssdk.core.pagination.sync.SdkIterable;
import software.amazon.awssdk.core.pagination.sync.SyncPageFetcher;
import software.amazon.awssdk.core.util.PaginatorUtils;
import software.amazon.awssdk.services.ec2.Ec2Client;
import software.amazon.awssdk.services.ec2.model.DescribePublicIpv4PoolsRequest;
import software.amazon.awssdk.services.ec2.model.DescribePublicIpv4PoolsResponse;
import software.amazon.awssdk.services.ec2.model.PublicIpv4Pool;

/**
 * <p>
 * Represents the output for the
 * {@link software.amazon.awssdk.services.ec2.Ec2Client#describePublicIpv4PoolsPaginator(software.amazon.awssdk.services.ec2.model.DescribePublicIpv4PoolsRequest)}
 * operation which is a paginated operation. This class is an iterable of
 * {@link software.amazon.awssdk.services.ec2.model.DescribePublicIpv4PoolsResponse} that can be used to iterate through
 * all the response pages of the operation.
 * </p>
 * <p>
 * When the operation is called, an instance of this class is returned. At this point, no service calls are made yet and
 * so there is no guarantee that the request is valid. As you iterate through the iterable, SDK will start lazily
 * loading response pages by making service calls until there are no pages left or your iteration stops. If there are
 * errors in your request, you will see the failures only after you start iterating through the iterable.
 * </p>
 *
 * <p>
 * The following are few ways to iterate through the response pages:
 * </p>
 * 1) Using a Stream
 * 
 * <pre>
 * {@code
 * software.amazon.awssdk.services.ec2.paginators.DescribePublicIpv4PoolsIterable responses = client.describePublicIpv4PoolsPaginator(request);
 * responses.stream().forEach(....);
 * }
 * </pre>
 *
 * 2) Using For loop
 * 
 * <pre>
 * {
 *     &#064;code
 *     software.amazon.awssdk.services.ec2.paginators.DescribePublicIpv4PoolsIterable responses = client
 *             .describePublicIpv4PoolsPaginator(request);
 *     for (software.amazon.awssdk.services.ec2.model.DescribePublicIpv4PoolsResponse response : responses) {
 *         // do something;
 *     }
 * }
 * </pre>
 *
 * 3) Use iterator directly
 * 
 * <pre>
 * {@code
 * software.amazon.awssdk.services.ec2.paginators.DescribePublicIpv4PoolsIterable responses = client.describePublicIpv4PoolsPaginator(request);
 * responses.iterator().forEachRemaining(....);
 * }
 * </pre>
 * <p>
 * <b>Note: If you prefer to have control on service calls, use the
 * {@link #describePublicIpv4Pools(software.amazon.awssdk.services.ec2.model.DescribePublicIpv4PoolsRequest)}
 * operation.</b>
 * </p>
 */
@Generated("software.amazon.awssdk:codegen")
public class DescribePublicIpv4PoolsIterable implements SdkIterable<DescribePublicIpv4PoolsResponse> {
    private final Ec2Client client;

    private final DescribePublicIpv4PoolsRequest firstRequest;

    private final SyncPageFetcher nextPageFetcher;

    public DescribePublicIpv4PoolsIterable(Ec2Client client, DescribePublicIpv4PoolsRequest firstRequest) {
        this.client = client;
        this.firstRequest = firstRequest;
        this.nextPageFetcher = new DescribePublicIpv4PoolsResponseFetcher();
    }

    @Override
    public Iterator<DescribePublicIpv4PoolsResponse> iterator() {
        return PaginatedResponsesIterator.builder().nextPageFetcher(nextPageFetcher).build();
    }

    /**
     * Returns an iterable to iterate through the paginated {@link DescribePublicIpv4PoolsResponse#publicIpv4Pools()}
     * member. The returned iterable is used to iterate through the results across all response pages and not a single
     * page.
     *
     * This method is useful if you are interested in iterating over the paginated member in the response pages instead
     * of the top level pages. Similar to iteration over pages, this method internally makes service calls to get the
     * next list of results until the iteration stops or there are no more results.
     */
    public final SdkIterable<PublicIpv4Pool> publicIpv4Pools() {
        Function<DescribePublicIpv4PoolsResponse, Iterator<PublicIpv4Pool>> getIterator = response -> {
            if (response != null && response.publicIpv4Pools() != null) {
                return response.publicIpv4Pools().iterator();
            }
            return Collections.emptyIterator();
        };
        return PaginatedItemsIterable.builder().pagesIterable(this).itemIteratorFunction(getIterator).build();
    }

    private class DescribePublicIpv4PoolsResponseFetcher implements SyncPageFetcher<DescribePublicIpv4PoolsResponse> {
        @Override
        public boolean hasNextPage(DescribePublicIpv4PoolsResponse previousPage) {
            return PaginatorUtils.isOutputTokenAvailable(previousPage.nextToken());
        }

        @Override
        public DescribePublicIpv4PoolsResponse nextPage(DescribePublicIpv4PoolsResponse previousPage) {
            if (previousPage == null) {
                return client.describePublicIpv4Pools(firstRequest);
            }
            return client.describePublicIpv4Pools(firstRequest.toBuilder().nextToken(previousPage.nextToken()).build());
        }
    }
}

==> ec2-2.13.13-sources.jar: software/amazon/awssdk/services/ec2/paginators/DescribePublicIpv4PoolsIterable.java <==
/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */

package software.amazon.awssdk.services.ec2.paginators;

import java.util.Collections;
import java.util.Iterator;
import java.util.function.Function;
import software.amazon.awssdk.annotations.Generated;
import software.amazon.awssdk.core.pagination.sync.PaginatedItemsIterable;
import software.amazon.awssdk.core.pagination.sync.PaginatedResponsesIterator;
import software.amazon.awssdk.core.pagination.sync.SdkIterable;
import software.amazon.awssdk.core.pagination.sync.SyncPageFetcher;
import software.amazon.awssdk.core.util.PaginatorUtils;
import software.amazon.awssdk.services.ec2.Ec2Client;
import software.amazon.awssdk.services.ec2.model.DescribePublicIpv4PoolsRequest;
import software.amazon.awssdk.services.ec2.model.DescribePublicIpv4PoolsResponse;
import software.amazon.awssdk.services.ec2.model.PublicIpv4Pool;

/**
 * <p>
 * Represents the output for the
 * {@link software.amazon.awssdk.services.ec2.Ec2Client#describePublicIpv4PoolsPaginator(software.amazon.awssdk.services.ec2.model.DescribePublicIpv4PoolsRequest)}
 * operation which is a paginated operation. This class is an iterable of
 * {@link software.amazon.awssdk.services.ec2.model.DescribePublicIpv4PoolsResponse} that can be used to iterate through
 * all the response pages of the operation.
 * </p>
 * <p>
 * When the operation is called, an instance of this class is returned. At this point, no service calls are made yet and
 * so there is no guarantee that the request is valid. As you iterate through the iterable, SDK will start lazily
 * loading response pages by making service calls until there are no pages left or your iteration stops. If there are
 * errors in your request, you will see the failures only after you start iterating through the iterable.
 * </p>
 *
 * <p>
 * The following are few ways to iterate through the response pages:
 * </p>
 * 1) Using a Stream
 * 
 * <pre>
 * {@code
 * software.amazon.awssdk.services.ec2.paginators.DescribePublicIpv4PoolsIterable responses = client.describePublicIpv4PoolsPaginator(request);
 * responses.stream().forEach(....);
 * }
 * </pre>
 *
 * 2) Using For loop
 * 
 * <pre>
 * {
 *     &#064;code
 *     software.amazon.awssdk.services.ec2.paginators.DescribePublicIpv4PoolsIterable responses = client
 *             .describePublicIpv4PoolsPaginator(request);
 *     for (software.amazon.awssdk.services.ec2.model.DescribePublicIpv4PoolsResponse response : responses) {
 *         // do something;
 *     }
 * }
 * </pre>
 *
 * 3) Use iterator directly
 * 
 * <pre>
 * {@code
 * software.amazon.awssdk.services.ec2.paginators.DescribePublicIpv4PoolsIterable responses = client.describePublicIpv4PoolsPaginator(request);
 * responses.iterator().forEachRemaining(....);
 * }
 * </pre>
 * <p>
 * <b>Note: If you prefer to have control on service calls, use the
 * {@link #describePublicIpv4Pools(software.amazon.awssdk.services.ec2.model.DescribePublicIpv4PoolsRequest)}
 * operation.</b>
 * </p>
 */
@Generated("software.amazon.awssdk:codegen")
public class DescribePublicIpv4PoolsIterable implements SdkIterable<DescribePublicIpv4PoolsResponse> {
    private final Ec2Client client;

    private final DescribePublicIpv4PoolsRequest firstRequest;

    private final SyncPageFetcher nextPageFetcher;

    public DescribePublicIpv4PoolsIterable(Ec2Client client, DescribePublicIpv4PoolsRequest firstRequest) {
        this.client = client;
        this.firstRequest = firstRequest;
        this.nextPageFetcher = new DescribePublicIpv4PoolsResponseFetcher();
    }

    @Override
    public Iterator<DescribePublicIpv4PoolsResponse> iterator() {
        return PaginatedResponsesIterator.builder().nextPageFetcher(nextPageFetcher).build();
    }

    /**
     * Returns an iterable to iterate through the paginated {@link DescribePublicIpv4PoolsResponse#publicIpv4Pools()}
     * member. The returned iterable is used to iterate through the results across all response pages and not a single
     * page.
     *
     * This method is useful if you are interested in iterating over the paginated member in the response pages instead
     * of the top level pages. Similar to iteration over pages, this method internally makes service calls to get the
     * next list of results until the iteration stops or there are no more results.
     */
    public final SdkIterable<PublicIpv4Pool> publicIpv4Pools() {
        Function<DescribePublicIpv4PoolsResponse, Iterator<PublicIpv4Pool>> getIterator = response -> {
            if (response != null && response.publicIpv4Pools() != null) {
                return response.publicIpv4Pools().iterator();
            }
            return Collections.emptyIterator();
        };
        return PaginatedItemsIterable.<DescribePublicIpv4PoolsResponse, PublicIpv4Pool> builder().pagesIterable(this)
                .itemIteratorFunction(getIterator).build();
    }

    private class DescribePublicIpv4PoolsResponseFetcher implements SyncPageFetcher<DescribePublicIpv4PoolsResponse> {
        @Override
        public boolean hasNextPage(DescribePublicIpv4PoolsResponse previousPage) {
            return PaginatorUtils.isOutputTokenAvailable(previousPage.nextToken());
        }

        @Override
        public DescribePublicIpv4PoolsResponse nextPage(DescribePublicIpv4PoolsResponse previousPage) {
            if (previousPage == null) {
                return client.describePublicIpv4Pools(firstRequest);
            }
            return client.describePublicIpv4Pools(firstRequest.toBuilder().nextToken(previousPage.nextToken()).build());
        }
    }
}
